@@ -1,12 +1,13 @@
 .onLoad <- function(libname, pkgname) {
 	if (!.jniInitialized) {
-		.jinit(parameters=c("-Xrs","-Xss1m"))
+	  .jinit(parameters=c("-Xrs", "-Xss1m",
+	                      paste0("-Djava.io.tmpdir=", tempdir())))
 	}
 	.jpackage(pkgname)
 	.jpackage("JavaGD")
 	
 	jars <- c("afcommons",
-			"commons-logging", "jgoodies-common", "forms",  
+			"commons-logging", "commons-lang", "jgoodies-common", "forms",  
 			"iText", "jhlir.jar", "jxlayer", 
 			"log4j", "swing-worker")
 	
